==> trustwise-2.1.10.tar.gz: trustwise-2.1.10/setup.py <==
from setuptools import setup, find_packages

setup(
    name="trustwise",
    version="2.1.10",
    description="Trustwise PyPi Package",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    author="Trustwise",
    author_email="nihal@trustwise.ai",
    url="https://github.com/trustwiseai/trustwise",
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    install_requires=[
        'aiohttp==3.9.1',
        'aiosignal==1.3.1',
        'annotated-types==0.6.0',
        'anyio==4.2.0',
        'attrs==23.2.0',
        'certifi==2023.11.17',
        'charset-normalizer==3.3.2',
        'click==8.1.7',
        'colorama==0.4.6',
        'dataclasses-json==0.6.3',
        'Deprecated==1.2.14',
        'distro==1.9.0',
        'frozenlist==1.4.1',
        'fsspec==2023.12.2',
        'docutils==0.20.1',
        'greenlet==3.0.3',
        'h11==0.14.0',
        'httpcore==1.0.2',
        'httpx==0.26.0',
        'importlib-metadata==7.0.1',
        'jaraco.classes==3.3.0',
        'idna==3.6',
        'joblib==1.3.2',
        'llama-index==0.9.36',
        'marshmallow==3.20.2',
        'multidict==6.0.4',
        'mypy-extensions==1.0.0',
        'nest-asyncio==1.6.0',
        'networkx==3.2.1',
        'nltk==3.8.1',
        'numpy==1.26.3',
        'openai==1.9.0',
        'packaging==23.2',
        'pandas==2.2.0',
        'pydantic==2.5.3',
        'pydantic_core==2.14.6',
        'Pygments==2.17.2',
        'python-dateutil==2.8.2',
        'python-dotenv==1.0.1',
        'pytz==2023.3.post1',
        'regex==2023.12.25',
        'requests==2.31.0',
        'six==1.16.0',
        'sniffio==1.3.0',
        'SQLAlchemy==2.0.25',
        'tenacity==8.2.3',
        'tiktoken==0.5.2',
        'tqdm==4.66.1',
        'typing-inspect==0.9.0',
        'typing_extensions==4.9.0',
        'tzdata==2023.4',
        'urllib3==2.1.0',
        'wrapt==1.16.0',
        'yarl==1.9.4',
        'zipp==3.17.0'
    ],)

==> trustwise-2.1.11.tar.gz: trustwise-2.1.11/setup.py <==
from setuptools import setup, find_packages

setup(
    name="trustwise",
    version="2.1.11",
    description="Trustwise PyPi Package",
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    author="Trustwise",
    author_email="nihal@trustwise.ai",
    url="https://github.com/trustwiseai/trustwise",
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    install_requires=[
        'aiohttp==3.9.1',
        'aiosignal==1.3.1',
        'annotated-types==0.6.0',
        'anyio==4.2.0',
        'attrs==23.2.0',
        'certifi==2023.11.17',
        'charset-normalizer==3.3.2',
        'click==8.1.7',
        'colorama==0.4.6',
        'dataclasses-json==0.6.3',
        'Deprecated==1.2.14',
        'distro==1.9.0',
        'frozenlist==1.4.1',
        'fsspec==2023.12.2',
        'docutils==0.20.1',
        'greenlet==3.0.3',
        'h11==0.14.0',
        'httpcore==1.0.2',
        'httpx==0.26.0',
        'importlib-metadata==7.0.1',
        'jaraco.classes==3.3.0',
        'idna==3.6',
        'joblib==1.3.2',
        'llama-index==0.9.36',
        'marshmallow==3.20.2',
        'multidict==6.0.4',
        'mypy-extensions==1.0.0',
        'nest-asyncio==1.6.0',
        'networkx==3.2.1',
        'nltk==3.8.1',
        'numpy==1.26.3',
        'openai==1.9.0',
        'packaging==23.2',
        'pandas==2.2.0',
        'pydantic==2.5.3',
        'pydantic_core==2.14.6',
        'Pygments==2.17.2',
        'python-dateutil==2.8.2',
        'python-dotenv==1.0.1',
        'pytz==2023.3.post1',
        'ratelimit==2.2.1',
        'regex==2023.12.25',
        'requests==2.31.0',
        'six==1.16.0',
        'sniffio==1.3.0',
        'SQLAlchemy==2.0.25',
        'tenacity==8.2.3',
        'tiktoken==0.5.2',
        'tqdm==4.66.1',
        'typing-inspect==0.9.0',
        'typing_extensions==4.9.0',
        'tzdata==2023.4',
        'urllib3==2.1.0',
        'wrapt==1.16.0',
        'yarl==1.9.4',
        'zipp==3.17.0'
    ],)
